get_members: Retrieve a list of memberships for one Matrix room.

View source: R/client.R

get_membersR Documentation

Retrieve a list of memberships for one Matrix room.

Description

This will fetch all memberships for a given room at the current point in time. Note that this will include currently joined users as well as all users that have been in the room historically. They can be differentiated by their membership field.

Usage

get_members(room_id)

Arguments

room_id

The room to receive members for.

Value

A list object from the Matrix API.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.