get_rooms: Get the room events for one or more Matrix rooms.

View source: R/rooms.R

get_roomsR Documentation

Get the room events for one or more Matrix rooms.

Description

Get the room events for one or more Matrix rooms.

Usage

get_rooms(room_ids, since, initial_sync = NULL)

Arguments

room_ids

A vector of room IDs to get data for.

since

Stop paginating when reaching this time.

initial_sync

Result of a prior call to sync(). This should be an initial sync meaning that the since parameter was not provided. If this is not provided, it will be called automatically.

Value

An object of class ChatStat_rooms.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.