plot_active_times: Create a plot showing the most active hours across the...

View source: R/plots.R

plot_active_timesR Documentation

Create a plot showing the most active hours across the provided rooms.

Description

Create a plot showing the most active hours across the provided rooms.

Usage

plot_active_times(rooms, timespan = lubridate::days(30))

Arguments

rooms

Rooms object to use. See rooms().

timespan

Maximum timespan to show in the plot.

Value

A ggplot2 object for plotting.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.