plot_daily_activity: Create a plot showing the daily activity across the provided...

View source: R/plots.R

plot_daily_activityR Documentation

Create a plot showing the daily activity across the provided rooms.

Description

Create a plot showing the daily activity across the provided rooms.

Usage

plot_daily_activity(rooms, timespan = lubridate::days(30))

Arguments

rooms

Rooms object to use. See rooms().

timespan

Maximum timespan to show in the plot.

Value

A ggplot2 object for plotting.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.