plot_time_of_day_activity: Create a plot showing the activity across the provided rooms...

View source: R/plots.R

plot_time_of_day_activityR Documentation

Create a plot showing the activity across the provided rooms by time-of-day.

Description

Create a plot showing the activity across the provided rooms by time-of-day.

Usage

plot_time_of_day_activity(rooms, timespan = lubridate::days(30))

Arguments

rooms

Rooms object to use. See rooms().

timespan

Maximum timespan to show in the plot.

Value

A ggplot2 object for plotting.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.