render_report: Render an HTML report based on a rooms object.

View source: R/utils.R

render_reportR Documentation

Render an HTML report based on a rooms object.

Description

Please note, that the current working directory has to be writable in order to save the output as well as the intermediate files.

Usage

render_report(rooms, output_file = NULL)

Arguments

rooms

Rooms object to base the report on. See rooms().

output_file

The place to write the report to. Defaults to chatstat_report.html.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.