rooms: Create the representation of matrix rooms.

View source: R/rooms.R

roomsR Documentation

Create the representation of matrix rooms.

Description

Create the representation of matrix rooms.

Usage

rooms(
  id,
  since = lubridate::now(),
  events = tibble::tibble(),
  members = tibble::tibble(),
  next_token = character()
)

Arguments

id

Matrix API identifiers of the rooms.

since

Date and time of the beginning of the included events.

events

One data.frame containing the events for all rooms.

members

A data.frame of current room memberships.

next_token

Token for the next sync. This should be set from the next_batch item from the last sync() that was used to update the rooms.

Value

An object of class ChatStat_rooms that stores the parameters as named list items.

See Also

get_rooms()


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.