update_rooms: Update room state using the Matrix API.

View source: R/rooms.R

update_roomsR Documentation

Update room state using the Matrix API.

Description

This function extends the existing state of the rooms with new events from the Matrix API. Events are added from a recent call to sync() and the gap to the existing timeline is filled with additional calls to the messages API.

Usage

update_rooms(rooms, sync = NULL)

Arguments

rooms

The rooms to update. See rooms().

sync

The result of a recent call to sync(). This will be called automatically, if the parameter is missing. Note, that this should be a sync that was done using the next_token item from the rooms object as the since parameter.


GregSutcliffe/ChatStat documentation built on March 18, 2022, 8:51 a.m.