| get_members | R Documentation |
This will fetch all memberships for a given room at the current point in
time. Note that this will include currently joined users as well as all users
that have been in the room historically. They can be differentiated by their
membership field.
get_members(room_id)
room_id |
The room to receive members for. |
A list object from the Matrix API.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.