| render_report | R Documentation |
Please note, that the current working directory has to be writable in order to save the output as well as the intermediate files.
render_report(rooms, output_file = NULL)
rooms |
Rooms object to base the report on. See |
output_file |
The place to write the report to. Defaults to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.