| update_rooms | R Documentation |
This function extends the existing state of the rooms with new events from
the Matrix API. Events are added from a recent call to sync() and the gap
to the existing timeline is filled with additional calls to the messages
API.
update_rooms(rooms, sync = NULL)
rooms |
The rooms to update. See |
sync |
The result of a recent call to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.